/*
 * Sonar, entreprise quality control tool.
 * Copyright (C) 2007-2008 Hortis-GRC SA
 * mailto:be_agile HAT hortis DOT ch
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.web;

import ch.hortis.sonar.model.ActiveRule;
import org.sonar.commons.DaoFacade;
import org.sonar.commons.rules.RulesDao;
import org.sonar.core.rules.RulesFacade;
import org.sonar.plugins.api.*;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class JRubyFacade {
  private DaoFacade dao;
  private PluginsIntrospector pluginsIntrospector;
  private RulesFacade rulesFacade;

  public static JRubyFacade getInstance() {
    return Application.getInstance().getContainer().getComponent(JRubyFacade.class);
  }
  
  public JRubyFacade(DaoFacade dao, PluginsIntrospector pluginsIntrospector, RulesFacade rulesFacade) {
    this.dao = dao;
    this.pluginsIntrospector = pluginsIntrospector;
    this.rulesFacade = rulesFacade;
  }

  public Set<Language> getLanguages() {
    return pluginsIntrospector.getLanguages();
  }

  public List<Plugin> getPluginsWithConfigurationExportable(Language language) {
    List<Plugin> targets = new ArrayList<Plugin>();
    for (Plugin plugin : pluginsIntrospector.getPluginsByLanguage(language.getKey())) {
      if (pluginsIntrospector.getRulesRepository(plugin.getKey()) instanceof ConfigurationExportable) {
        targets.add(plugin);
      }
    }
    return targets;
  }

  public List<Plugin> getPluginsWithConfigurationImportable(Language language) {
    List<Plugin> targets = new ArrayList<Plugin>();
    for (Plugin plugin : pluginsIntrospector.getPluginsByLanguage(language.getKey())) {
      if (pluginsIntrospector.getRulesRepository(plugin.getKey()) instanceof ConfigurationImportable) {
        targets.add(plugin);
      }
    }
    return targets;
  }

  public String exportConfiguration(int profileId, String pluginKey) {
    ConfigurationExportable configurationExportable = (ConfigurationExportable) pluginsIntrospector.getRulesRepository(pluginKey);
    RulesDao rulesDao = dao.getRulesDao();
    return configurationExportable.exportConfiguration(rulesDao.getProfileById(profileId));
  }

  public void importConfiguration(int profileId, String configuration, String pluginKey) {
    ConfigurationImportable configurationImportable = (ConfigurationImportable) pluginsIntrospector.getRulesRepository(pluginKey);
    List<ActiveRule> activeRules = configurationImportable.importConfiguration(configuration);
    dao.getRulesDao().addActiveRulesToProfile(activeRules, profileId, pluginKey);
    dao.getDatabaseManager().commit();
  }

  public Map<String, Long> getRulesCountByCategory(String language){
    return rulesFacade.getRulesCountByCategory(language);
  }
  
}
